Version 3.0～4.0
=================

Version3.0～4.0までのリリースノートです。

## :package: 3.1.1

:fontawesome-solid-calendar: `2022-03-31`

!!! bug "`jumeaux viewer`コマンドが利用できない不具合を修正しました"

## :package: 3.1.0

:fontawesome-solid-calendar: `2022-03-06`

??? info "URLのホスト部分を無視して文字列比較てきるtemplate用関数を追加しました"

    * 環境によってレスポンスのURLにおけるホストが変わる場合に便利です
    * 詳細は[equals_without_host]をご覧ください

## :package: 3.0.1

:fontawesome-solid-calendar: `2022-02-18`

!!! bug "依存関係のバージョンによってJumeauxが実行できない不具合を修正しました"

## :package: 3.0.0

:fontawesome-solid-calendar: `2021-06-03`

??? info "レスポンスヘッダの比較ができるようになりました"

    * デフォルトではレスポンスヘッダの保存/比較はしません (今まで通り)
        * [config]の`judge_response_header`を`true`にする必要があります
    * レスポンスヘッダは[report] > [trial]内に保存されます
        * 詳細は[ResponseSummary] > `headers`をご覧ください
    * [config] > `ignore_response_header_keys`で指定したkeyは差分があっても無視できます
        * [trial] > `diffs_by_cognition`のような機能はありません

[report]: ../getstarted/report.md
[config]: ../getstarted/configuration.md

[trial]: ../models/trial.md
[ResponseSummary]: ../models/trial.md#responsesummary
[equals_without_host]: ../template.md#equals_without_hostone-str-other-str
